==> haskell-charset-0.3.7.1-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-AR12ltPmqbkDSmwoUvt0T3
key: charset-0.3.7.1-AR12ltPmqbkDSmwoUvt0T3
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category
abi: e164eabf97296edfaeb680a691524417
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/charset-0.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-AR12ltPmqbkDSmwoUvt0T3
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn=e523ad11a5c5a0977b92d6afb6220c8b
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.7.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: charset
version: 0.3.7.1
id: charset-0.3.7.1-BUmjZgjug5aBoB7wCSF0Mt
key: charset-0.3.7.1-BUmjZgjug5aBoB7wCSF0Mt
license: BSD3
copyright: (c) Edward Kmett 2010-2012
maintainer: ekmett@gmail.com
stability: Experimental
homepage: http://github.com/ekmett/charset
synopsis: Fast unicode character sets based on complemented PATRICIA tries
description:
    Fast unicode character sets based on complemented PATRICIA tries
category: Data
author: Edward Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category
abi: c3610079929920c8243c16ea89eb7879
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/charset-0.3.7.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/charset-0.3.7.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/charset-0.3.7.1
hs-libraries: HScharset-0.3.7.1-BUmjZgjug5aBoB7wCSF0Mt
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
haddock-interfaces: /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html: /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
